CounterPolicy

Enum CounterPolicy 

pub enum CounterPolicy {
    Rollover {
        bits: u8,
        step: u32,
    },
    None,
}
How counters should evolve across a session.

Variants



Rollover

Monotonic with rollover of bits width and fixed step (usually 1).

Fields

bits: u8
step: u32


None

No policy (accept any counter).

Implementations

Source

impl CounterPolicy

pub fn next(self, prev: Option<u32>) -> u32

Compute the next counter to use for transmission given the previous one.

pub fn ok(self, prev: Option<u32>, next: u32) -> bool

Validate whether next is the correct successor of prev.