pub enum E2eError {
Length,
Crc,
DataId,
Counter,
Unsupported,
}Expand description
Errors that may happen during protect/check/unwrap.
Variants
Length
Payload or frame length is out of the profile’s constraints.
Crc
CRC (integrity) verification failed.
DataId
Data-ID (or Data-ID-List based mapping) check failed.
Counter
Counter policy violation (gap, wrong step, illegal value).
Unsupported
Feature or operation is not supported by the active profile.